Minimum

Trait Minimum 

pub trait Minimum: Ord {
    const MIN: Self;
}
Trait for types for which a minimum possible value exists.

This trait must be implemented for any K key type in the ConcurrentMap.

Required Associated Constants

const MIN: Self

The returned value must be less than or equal to all possible values for this type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Minimum for &str

Source

const MIN: Self = ""

Source

impl Minimum for ()

Source

const MIN: Self = ()

Source

impl Minimum for NonZeroI8

Source

const MIN: Self = NonZeroI8::MIN

Source

impl Minimum for NonZeroI16

Source

const MIN: Self = NonZeroI16::MIN

Source

impl Minimum for NonZeroI32

Source

const MIN: Self = NonZeroI32::MIN

Source

impl Minimum for NonZeroI64

Source

const MIN: Self = NonZeroI64::MIN

Source

impl Minimum for NonZeroI128

Source

const MIN: Self = NonZeroI128::MIN

Source

impl Minimum for NonZeroIsize

Source

const MIN: Self = NonZeroIsize::MIN

Source

impl Minimum for NonZeroU8

Source

const MIN: Self = NonZeroU8::MIN

Source

impl Minimum for NonZeroU16

Source

const MIN: Self = NonZeroU16::MIN

Source

impl Minimum for NonZeroU32

Source

const MIN: Self = NonZeroU32::MIN

Source

impl Minimum for NonZeroU64

Source

const MIN: Self = NonZeroU64::MIN

Source

impl Minimum for NonZeroU128

Source

const MIN: Self = NonZeroU128::MIN

Source

impl Minimum for NonZeroUsize

Source

const MIN: Self = NonZeroUsize::MIN

Source

impl Minimum for String

Source

const MIN: Self

Source

impl Minimum for bool

Source

const MIN: Self = false

Source

impl Minimum for i8

Source

const MIN: Self = i8::MIN

Source

impl Minimum for i16

Source

const MIN: Self = i16::MIN

Source

impl Minimum for i32

Source

const MIN: Self = i32::MIN

Source

impl Minimum for i64

Source

const MIN: Self = i64::MIN

Source

impl Minimum for i128

Source

const MIN: Self = i128::MIN

Source

impl Minimum for isize

Source

const MIN: Self = isize::MIN

Source

impl Minimum for u8

Source

const MIN: Self = u8::MIN

Source

impl Minimum for u16

Source

const MIN: Self = u16::MIN

Source

impl Minimum for u32

Source

const MIN: Self = u32::MIN

Source

impl Minimum for u64

Source

const MIN: Self = u64::MIN

Source

impl Minimum for u128

Source

const MIN: Self = u128::MIN

Source

impl Minimum for usize

Source

const MIN: Self = usize::MIN

Source

impl<A: Minimum, B: Minimum, C: Minimum, D: Minimum, E: Minimum, F: Minimum> Minimum for (A, B, C, D, E, F)

Source

const MIN: Self

Source

impl<A: Minimum, B: Minimum, C: Minimum, D: Minimum, E: Minimum> Minimum for (A, B, C, D, E)

Source

const MIN: Self

Source

impl<A: Minimum, B: Minimum, C: Minimum, D: Minimum> Minimum for (A, B, C, D)

Source

const MIN: Self

Source

impl<A: Minimum, B: Minimum, C: Minimum> Minimum for (A, B, C)

Source

const MIN: Self

Source

impl<A: Minimum, B: Minimum> Minimum for (A, B)

Source

const MIN: Self

Source

impl<T: Maximum> Minimum for Reverse<T>

Source

const MIN: Self

Source

impl<T: Minimum, const LEN: usize> Minimum for [T; LEN]

Source

const MIN: Self

Source

impl<T: Ord> Minimum for &[T]

Source

const MIN: Self

Source

impl<T: Ord> Minimum for Vec<T>

Source

const MIN: Self

Implementors